@@ -91,6 +91,9 @@ url_visited_cb (EphyHistoryService *service,
 {
   EphyHistoryRecord *record;
 
+  if (!url->sync_id)
+    return;
+
   record = ephy_history_record_new (url->sync_id, url->title, url->url, url->last_visit_time);
   g_signal_emit_by_name (self, "synchronizable-modified", record, TRUE);
   g_object_unref (record);
@@ -103,6 +106,9 @@ url_deleted_cb (EphyHistoryService *service,
 {
   EphyHistoryRecord *record;
 
+  if (!url->sync_id)
+    return;
+
   record = ephy_history_record_new (url->sync_id, url->title, url->url, url->last_visit_time);
   g_signal_emit_by_name (self, "synchronizable-deleted", record);
   g_object_unref (record);
